from time import time
import setuptools
with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()
setuptools.setup(
    name='abstract_pandas',
    version='0.0.44.18',
    author='putkoff',
    author_email='partners@abstractendeavors.com',
    description="",
    long_description=long_description,
    long_description_content_type='text/markdown',
    classifiers=[
          'Development Status :: 3 - Alpha',
          'Intended Audience :: Developers',
          'License :: OSI Approved :: MIT License',
          'Programming Language :: Python :: 3',
          'Programming Language :: Python :: 3.11',
      ],
    install_requires=[
        'abstract_essentials',
        'pandas',
        'openpyxl',
        ],
    extras_require={
        # Heavy/optional libraries are imported lazily by abstract_pandas, so they
        # are only needed when the corresponding feature is actually used.
        'geo': ['geopandas', 'shapely'],
        'ods': ['odfpy', 'ezodf', 'lxml'],
        'upload': ['Werkzeug'],
        'pdf': ['pdfplumber', 'pytesseract', 'pdf2image'],
        'all': ['geopandas', 'shapely', 'odfpy', 'ezodf', 'lxml',
                'Werkzeug', 'pdfplumber', 'pytesseract', 'pdf2image'],
        },
    package_dir={"": "src"},
    packages=setuptools.find_packages(where="src"),
    python_requires=">=3.6",
    # Add this line to include wheel format in your distribution
    setup_requires=['wheel'],
)
